# django-multitenancy
Django Multitenancy is a Django app that handles user subscriptions for saas multi tenant apps.
The aim of this project is to speed up the process of launch your saas app.
<p align="center">
    <br>
    <a href="https://github.com/tekanokhambane/django-multitenancy/actions">
        <img src="https://github.com/tekanokhambane/django-multitenancy/workflows/Django Multitenancy CI/badge.svg" alt="Build Status" />
    </a>
    <a href="https://opensource.org/licenses/BSD-3-Clause">
        <img src="https://img.shields.io/badge/license-BSD-blue.svg" alt="License" />
    </a>
</p>


#### :warning: This package is still in its alpha stage and is not ready for production

![django-multitenancy screenshot](https://github.com/tekanokhambane/django-multitenancy/blob/main/.github/dango-multitenancy-screenshot.png)

## Requirements
- Python 3.6+
- Django 3.0+

## Installation
1. Clone the repository:
```
git clone git@github.com:tekanokhambane/django-multitenancy.git

```


### 🔥 Features

-   Manage Customers and Teams
-   Helpdesk, Ticket system
-   Create and manage templates
-   Automated subscriptions and billing systems
-   Admin, Staff and Client dashboard
-   Customizable pricing plans
-   Manage subscriptions - Activate, suspend, deactivate subscription
-   Runs on a Raspberry Pi or a multi-datacenter cloud platform
-   Domain management 
-   Use for any Saas App


